@@ -248,7 +248,17 @@ class ClBuilderUpdateAction(Action):
                       'method': 'Builder.emerge_ask('
                                 'update.cl_update_pretend_set,'
                                 '"-uDN","--changed-deps",'
-                                '"@world")'
+                                '"@world")',
+                      'condition': lambda Get:
+                          Get('cl_builder_rebuild_changed_set') == 'on'
+                      },
+                     {'name': 'update_world',
+                      'message': __("Calculating dependencies"),
+                      'method': 'Builder.emerge_ask('
+                                'update.cl_update_pretend_set,'
+                                '"-uDN","@world")',
+                      'condition': lambda Get:
+                          Get('cl_builder_rebuild_changed_set') != 'on'
                       }
                  ],
                  'condition': lambda Get: (
